package com.javacodegeeks.client;

import java.util.ArrayList;
import java.util.List;

import com.google.gwt.core.client.EntryPoint;
import com.google.gwt.user.cellview.client.CellTable;
import com.google.gwt.user.cellview.client.HasKeyboardSelectionPolicy.KeyboardSelectionPolicy;
import com.google.gwt.user.cellview.client.TextColumn;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.FlexTable;
import com.google.gwt.user.client.ui.RootPanel;
import com.google.gwt.user.client.ui.VerticalPanel;
import com.google.gwt.view.client.SelectionChangeEvent;
import com.google.gwt.view.client.SingleSelectionModel;

/**
 * Entry point classes define <code>onModuleLoad()</code>.
 */
public class GWTTable implements EntryPoint {

	/**
	 * This is the entry point method.
	 */
	public void onModuleLoad() {
		FlexTable flexTable = createFlexTable();

		CellTable<Address> cellTableOfAddress = new CellTable<Address>();
		// The policy that determines how keyboard selection will work. Keyboard
		// selection is enabled.
		cellTableOfAddress.setKeyboardSelectionPolicy(KeyboardSelectionPolicy.ENABLED);

		// Add a text columns to show the details.
		TextColumn<Address> columnFirstLine = new TextColumn<Address>() {
			@Override
			public String getValue(Address object) {
				return object.getFirstLineOfAddress();
			}
		};
		cellTableOfAddress.addColumn(columnFirstLine, "First line");

		TextColumn<Address> columnSecondLine = new TextColumn<Address>() {
			@Override
			public String getValue(Address object) {
				return object.getSecondLineOfAddress();
			}
		};
		cellTableOfAddress.addColumn(columnSecondLine, "Second line");

		TextColumn<Address> townColumn = new TextColumn<Address>() {
			@Override
			public String getValue(Address object) {
				return object.getTown();
			}
		};
		cellTableOfAddress.addColumn(townColumn, "Town");

		TextColumn<Address> countryColumn = new TextColumn<Address>() {
			@Override
			public String getValue(Address object) {
				return object.getCountry();
			}
		};
		cellTableOfAddress.addColumn(countryColumn, "Country");

		final SingleSelectionModel<Address> selectionModel = new SingleSelectionModel<Address>();
		cellTableOfAddress.setSelectionModel(selectionModel);
		selectionModel.addSelectionChangeHandler(new SelectionChangeEvent.Handler() {

			public void onSelectionChange(SelectionChangeEvent event) {

				Address selectedAddress = selectionModel.getSelectedObject();
				if (selectedAddress != null) {
					Window.alert("Selected: First line: " + selectedAddress.getFirstLineOfAddress() + ", Second line: " + selectedAddress.getSecondLineOfAddress());
				}
			}
		});
		
		List<Address> addresses = new ArrayList<Address>() {
			{
				add(new Address("Cell Table", "First line", "Oxford", "UK"));
				add(new Address("Cell Table", "Second line", "Cambrige", "UK"));
				
			}
		};
		
		cellTableOfAddress.setRowCount(addresses.size(), true);
		cellTableOfAddress.setRowData(0, addresses);
		
		VerticalPanel vp = new VerticalPanel();
		vp.setBorderWidth(1);
		vp.add(flexTable);
		vp.add(cellTableOfAddress);
		
		RootPanel.get("container").add(vp);
	}

	private FlexTable createFlexTable() {
		FlexTable flexTable = new FlexTable();
		flexTable.setBorderWidth(1);
		flexTable.setText(0, 0, "This is an example of flextable");
		flexTable.setText(2, 2, "This is also an example of flextable");
		flexTable.getFlexCellFormatter().setColSpan(1, 0, 3);
		return flexTable;
	}
}
